@@ -2,15 +2,16 @@ from http.cookiejar import Cookie
 from http.cookiejar import CookieJar
 from platform import python_version
 from platform import uname
-from time import sleep
+from re import sub
 from typing import Optional
 from typing import Union
+from urllib.robotparser import RobotFileParser
 
-from cfscrape import CloudflareScraper
-from cfscrape import create_scraper
+from cfscrape import CloudflareScraper  # type: ignore
+from cfscrape import create_scraper  # type: ignore
 from requests import Response
-from requests import get as get_raw
-from urllib3.exceptions import IncompleteRead
+from requests import Session
+from urllib3.exceptions import IncompleteRead  # type: ignore
 
 from .__version__ import __version__
 
@@ -35,18 +36,10 @@ def make_session(cookies: Union[list[dict[str, str]], CookieJar]) -> CloudflareS
     return session
 
 
-def get_robots() -> dict[str, list[str]]:
-    res: Response = get_raw(join_url(root, "robots.txt"), headers={"User-Agent": user_agent})
-
-    res.raise_for_status()
-
-    robot: dict[str, Union[int, str, list[str]]] = {}
-
-    for elem in filter(lambda r: r not in ("", "#"), res.text.split("\n")):
-        key, value = elem.split(":", 1)
-        robot[key] = [*robot.get(key, []), value.strip()]
-
-    return robot
+def get_robots(session: Session) -> RobotFileParser:
+    robots: RobotFileParser = RobotFileParser(url := join_url(root, "robots.txt"))
+    robots.parse(sub(r"\n[#\n]+", "\n", session.get(url).text).splitlines())
+    return robots
 
 
 def get(session: CloudflareScraper, path: str, **params) -> Response:
@@ -54,10 +47,10 @@ def get(session: CloudflareScraper, path: str, **params) -> Response:
 
 
 def stream_binary(session: CloudflareScraper, url: str, *, chunk_size: Optional[int] = None) -> bytes:
-    stream: Response = session.get(url, stream=chunk_size is not None)
+    stream: Response = session.get(url, stream=True)
     stream.raise_for_status()
 
-    file_binary: bytes = bytes().join(stream.iter_content(chunk_size=chunk_size)) if chunk_size else stream.content
+    file_binary: bytes = bytes().join(stream.iter_content(chunk_size))
 
     if (length := int(stream.headers.get("Content-Length", 0))) > 0 and length != len(file_binary):
         raise IncompleteRead(l := len(file_binary), length - l)
