@@ -2,8 +2,8 @@ from datetime import datetime
 from typing import Optional
 from typing import Union
 
-from bs4 import BeautifulSoup
-from bs4.element import Tag
+from bs4 import BeautifulSoup  # type: ignore
+from bs4.element import Tag  # type: ignore
 
 from .connection import join_url
 from .connection import root
@@ -14,7 +14,14 @@ from .user import UserPartial
 
 
 class Journal:
+    """
+    This class contains a journal's information.
+    """
+
     def __init__(self, journal_item: Union[Tag, BeautifulSoup] = None):
+        """
+        :param journal_item: The element from which to parse the journal, a Tag from a journals page or a journal page.
+        """
         assert journal_item is None or isinstance(journal_item, (BeautifulSoup, Tag))
 
         self.journal_item: Optional[Union[Tag, BeautifulSoup]] = journal_item
@@ -43,20 +50,29 @@ class Journal:
         return f"{self.id} {self.author} {self.title}"
 
     @property
-    def url(self):
+    def url(self) -> str:
+        """
+        Compose the full URL to the journal.
+        :return: The URL to the journal.
+        """
         return join_url(root, "journal", self.id)
 
     def parse(self, journal_item: Union[Tag, BeautifulSoup] = None):
+        """
+        Parse a journal Tag or page, overrides any information already present in the object.
+        :param journal_item: The element from which to parse the journal, a Tag from a journals page or a journal page.
+        """
         assert journal_item is None or isinstance(journal_item, (BeautifulSoup, Tag))
         self.journal_item = journal_item or self.journal_item
         if self.journal_item is None:
             return
 
+        parsed: dict
         if isinstance(self.journal_item, BeautifulSoup):
             check_page_raise(self.journal_item)
-            parsed: dict = parse_journal_page(self.journal_item)
+            parsed = parse_journal_page(self.journal_item)
         else:
-            parsed: dict = parse_journal_section(self.journal_item)
+            parsed = parse_journal_section(self.journal_item)
 
         self.id = parsed["id"]
         self.title = parsed["title"]
